@@ -265,7 +265,7 @@ class CompletionPlugin(SpyderPluginV2):
         statusbar = self.get_plugin(Plugins.StatusBar)
         if statusbar:
             for sb in container.all_statusbar_widgets():
-                statusbar.add_status_widget(sb, 0)
+                statusbar.add_status_widget(sb)
 
         if self.main:
             self.main.sig_pythonpath_changed.connect(
@@ -685,6 +685,9 @@ class CompletionPlugin(SpyderPluginV2):
     def _instantiate_and_register_provider(
             self, Provider: SpyderCompletionProvider):
         provider_name = Provider.COMPLETION_PROVIDER_NAME
+        if provider_name in self._available_providers:
+            return
+
         self._available_providers[provider_name] = Provider
 
         logger.debug("Completion plugin: Registering {0}".format(
